# Contributing
## Prerequisites
- Install `python`
- Fork the journalyze repo
- Run `git clone https://github.com/{your username}/journalyze.git`
- In cloned repo, install the development dependencies by running `make develop`

## Contributing
- Make your changes
- Commit your changes and push them to your forked Github repo

## Before opening a pull request
- When you are satisfied with your changes, please run the following to ensure that there are no formatting issues and all the tests pass: 

`make build`

`make format`

`make lint` 

`make test`

`make coverage`

- If you are adding new features, please also add tests for them.


## Pull requests
- Open a pull request back to the main Github repo.
- After a pull request is opened, I will review it and merge it with the main Github repo.